import { ProColumns } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";
import { Badge, Button, Space, Tag } from "antd";

export const columns = (submit: (params: { orderNo: string }) => void): ProColumns<any>[] => {
    let { getEnum } = useModel("global")
    let orderTypeObj: any = { '1': '书币充值', "2": "vip充值", "3": "购买整本" };
    return [
        {
            title: 'openId',
            dataIndex: 'openId',
            align: 'center',
            width: 70,
            ellipsis: true,
            render: (_, row) => {
                return row?.wechatMiniappUser?.openId
            }
        },
        {
            title: "小说名称",
            dataIndex: 'bookName',
            key: "bookName",
            align: "center",
            render: (a, b: any) => {
                return b?.bookInfo?.bookName || "-"
            }
        },
        {
            title: "支付渠道",
            dataIndex: 'payChannel',
            key: "payChannel",
            align: "center",
            valueType: 'select',
            valueEnum: getEnum("PAY_CHANNEL", 'map'),
        },
        {
            title: "支付金额",
            dataIndex: 'amount',
            key: "amount",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "订单类型",
            dataIndex: 'orderType',
            key: "orderType",
            valueType: 'select',
            valueEnum: getEnum("ORDER_TYPE", "map"),
            align: "center",
        },
        {
            title: "订单状态",
            dataIndex: 'orderStatus',
            key: "orderStatus",
            valueType: 'select',
            align: "center",
            valueEnum: getEnum("ORDER_STATUS", 'stateObj', { 2: 'success', 1: "warning" })
        },
        {
            title: "用户订单号",
            dataIndex: 'orderNo',
            key: "orderNo",
            align: "center",
        },
        {
            title: "商户订单号",
            dataIndex: 'merchantOrderId',
            key: "merchantOrderId",
            align: "center",
        },
        {
            title: "下单时间",
            dataIndex: 'orderTime',
            key: "orderTime",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "下单场景",
            dataIndex: 'orderCondition',
            key: "orderCondition",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "支付时间",
            tooltip: "实际到账时间",
            dataIndex: 'payTime',
            key: "payTime",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "充值次数",
            dataIndex: 'chargeNum',
            key: "chargeNum",
            hideInSearch: true,
            align: "center",
            render: (_, row) => {
                return row?.wechatMiniappUser?.chargeNum
            }
        },
        {
            title: "上报金额",
            dataIndex: 'backMoney',
            key: "backMoney",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "上报状态",
            dataIndex: 'backStatus',
            key: "backStatus",
            hideInSearch: true,
            align: "center",
            render: (_, row) => {
                let obj = getEnum("BACK_STATUS", "stateObj", { "0": 'default', "-1": "error", "1": "processing", "2": "success", "3": "warning" })
                let isShowBtn = [1, -1].includes(row?.backStatus)
                return <Space>{obj[row.backStatus]?.text}{isShowBtn && <Tag.CheckableTag checked onClick={() => { submit({ orderNo: row.orderNo }) }}>上报</Tag.CheckableTag>}</Space>
            }
        },
        {
            title: '归因渠道',
            dataIndex: 'userChannel',
            width: 170,
            align: 'center',
            ellipsis: true,
            valueType: 'select',
            valueEnum: getEnum("USER_CHANNEL", "map"),
            render: (_, row) => {
                let str = getEnum("USER_CHANNEL", "map").get(row?.wechatMiniappUser?.userChannel)
                return str
            }
        },
        {
            title: '渠道名称',
            dataIndex: 'userSource',
            align: 'center',
            ellipsis: true,
            render: (_, row) => {
                return row?.wechatMiniappUser?.userSource
            }
        },
        {
            title: "用户注册时间",
            dataIndex: 'createTime',
            key: "createTime",
            hideInSearch: true,
            align: "center",
            render: (_, row) => {
                return row?.wechatMiniappUser?.createTime
            }
        },
        // 搜索条件
        {
            title: "开始时间",
            dataIndex: 'startTime',
            valueType: 'dateTime',
            hideInTable: true
        },
        {
            title: "结束时间",
            dataIndex: 'endTime',
            valueType: 'dateTime',
            hideInTable: true
        },
        {
            title: "最小充值金额",
            dataIndex: 'amountMin',
            valueType: 'money',
            hideInTable: true,
        },
        {
            title: "最大充值金额",
            dataIndex: 'amountMax',
            valueType: 'money',
            hideInTable: true
        },
    ];
}